@@ -5,7 +5,7 @@ from twisted.internet.defer import inlineCallbacks
 
 from vortex.DeferUtil import vortexLogFailure
 from vortex.VortexFactory import VortexFactory
-from vortex.rpc.run_server_test import myRemoteAddMethod
+from vortex.rpc.test.RPCTest import myRemoteAddMethod
 
 logger = logging.getLogger(__name__)
 logging.basicConfig()
@@ -13,13 +13,14 @@ logging.basicConfig()
 
 @inlineCallbacks
 def connect():
-    yield VortexFactory.createTcpClient("sendVortexName", "127.0.0.1", 10101)
+    yield VortexFactory.createWebsocketClient(
+        "sendVortexName", "127.0.0.1", 10101, "ws://127.0.0.1:10101/vortexws"
+    )
 
     reactor.callLater(2, callRpc)
 
 
 def callRpc():
-
     d = myRemoteAddMethod(7, kwarg1=4)
     d.addCallback(lambda v: logger.debug("SUCCESSS, result = %s", v))
     d.addErrback(vortexLogFailure, logger)
@@ -28,7 +29,6 @@ def callRpc():
 
 
 if __name__ == "__main__":
-
     reactor.callLater(0, logger.info, "RPCTest client running")
     reactor.callLater(0, connect)
     reactor.run()
